@@ -14,16 +14,10 @@
 
 from typing import Any, Union, Tuple
 
-from .object import Object
+from .std import StandardObject
 
 
-class Device(Object):
-
-    SUPER_CLASS_CODE = 0x0000
+class Device(StandardObject):
 
     def __init__(self, code: Union[int, Tuple[int, int], Tuple[int, int, int], Any]):
-        super().__init__()
-        self.set_code(code)
-
-    def __del__(self):
-        super().__del__()
+        super().__init__(code)
