@@ -13,6 +13,6 @@
 # limitations under the License.
 
 from .database import Database
-from .object import StandardDevice
+from .object import StandardObject
 
-__all__ = ['Database', 'StandardDevice']
+__all__ = ['Database', 'StandardObject']
