@@ -1,6 +1,6 @@
 # Copyright (C) 2021 Satoshi Konno. All rights reserved.
 #
-# Licensed under the Apache License, Version 2.0 (the "License");
+# Licensed under the Apache License, Version 2.0 (the "License")
 # you may not use this file except in compliance with the License.
 # You may obtain a copy of the License at
 #
@@ -12,20 +12,18 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from typing import Optional, Union, Tuple, Any
-from ..device import Device
+from typing import Any, Union, Tuple
+
+from ..super_object import SuperObject
 from ..object import Object
 from .database import Database
 
 
-class StandardDevice(Device):
-    """StandardDevice represents a standard device object of ECHONET Lite.
-    """
-    __database: Database
+class StandardObject(SuperObject):
 
-    def __init__(self, code: Union[int, Tuple[int, int], Tuple[int, int, int], Any] = None):
-        self.__database = Database()
-        super().__init__(code)
+    def __init__(self, code: Union[int, Tuple[int, int], Tuple[int, int, int], Any]):
+        super().__init__()
+        self.set_code(code)
 
     def set_code(self, code: Union[int, Tuple[int, int], Tuple[int, int, int], Any]) -> bool:
         """Sets the spcecified code as the object code.
@@ -38,11 +36,15 @@ class StandardDevice(Device):
         """
         if not super().set_code(code):
             return False
-        mandatory_obj = self.__database.get_object((0x00, 0x00))
-        if isinstance(mandatory_obj, Object):
-            self._set_object_properties(mandatory_obj)
-        std_obj = self.__database.get_object((self.group_code, self.class_code))
+
+        std_obj = Database().get_object(SuperObject.CODE)
         if isinstance(std_obj, Object):
             self._set_object_properties(std_obj)
 
-        return True
+        std_obj = Database().get_object(code)
+        if isinstance(std_obj, Object):
+            self._set_object_properties(std_obj)
+        return self._update_property_map_properties()
+
+    def __del__(self):
+        super().__del__()
